@@ -2,6 +2,7 @@
 from __future__ import with_statement
 import os
 import unittest
+import six
 
 from sqlalchemy.ext.declarative import declarative_base
 from ziggurat_foundations.models import UserMixin
@@ -174,6 +175,11 @@ class ModelTestCase(BaseTestCase):
         dict_ = created_user.get_dict()
         self.assertEqual(len(dict_), 8)
 
+    def test_get_dict_excluded(self):
+        created_user = self._addUser()
+        dict_ = created_user.get_dict(exclude_keys=['user_name'])
+        assert 'user_name' not in dict_
+
     def test_appstruct(self):
         created_user = self._addUser()
         appstruct = created_user.get_appstruct()
@@ -375,13 +381,13 @@ class UserTestCase(BaseTestCase):
         rand_str = User.generate_random_string()
 
         self.assertEqual(len(rand_str), 7)
-        self.assertIsInstance(rand_str, unicode)
+        self.assertIsInstance(rand_str, six.string_types)
 
     def test_generate_random_pass(self):
         rand_str = User.generate_random_pass()
 
         self.assertEqual(len(rand_str), 7)
-        self.assertIsInstance(rand_str, unicode)
+        self.assertIsInstance(rand_str, six.string_types)
 
         rand_str = User.generate_random_pass(20)
         self.assertEqual(len(rand_str), 20)
@@ -565,51 +571,53 @@ class UserTestCase(BaseTestCase):
     def test_resources_with_direct_user_perms(self):
         self.__set_up_user_group_and_perms()
         # test_perm1 from group perms should be ignored
-        self.assertEqual(self.resource.direct_perms_for_user(self.user,
-                                                    db_session=self.session),
-                [(1, u'foo_perm'), (1, u'test_perm2')]
-                         )
+        first = self.resource.direct_perms_for_user(self.user, db_session=self.session)
+        second = [(1, u'foo_perm'), (1, u'test_perm2')]
+        if six.PY2:
+            return self.assertItemsEqual(first, second)
+        return self.assertCountEqual(first, second)
 
     def test_resources_with_direct_group_perms(self):
         self.__set_up_user_group_and_perms()
         # test_perm1 from group perms should be ignored
-        self.assertEqual(self.resource.group_perms_for_user(self.user,
-                                                db_session=self.session),
-                [('group:1', u'group_perm')]
-                )
+        first = self.resource.group_perms_for_user(self.user, db_session=self.session)
+        second = [('group:1', u'group_perm')]
+        if six.PY2:
+            return self.assertItemsEqual(first, second)
+        return self.assertCountEqual(first, second)
 
     def test_resources_with_user_perms(self):
         self.__set_up_user_group_and_perms()
-        self.assertEqual(
-                sorted(self.resource.perms_for_user(self.user,
-                                                    db_session=self.session)),
-                sorted([(1, u'foo_perm'),
-                        (u'group:1', u'group_perm'),
-                        (1, u'test_perm2')])
-                        )
+        first = self.resource.perms_for_user(self.user, db_session=self.session)
+        second = [(1, u'foo_perm'),
+                  (u'group:1', u'group_perm'),
+                  (1, u'test_perm2')]
+        if six.PY2:
+            return self.assertItemsEqual(first, second)
+        return self.assertCountEqual(first, second)
 
     def test_users_for_perm(self):
         self.__set_up_user_group_and_perms()
-        self.assertEqual(
-                sorted(self.resource.users_for_perm(u'foo_perm',
-                                                    db_session=self.session)),
-                sorted([(self.user, u'foo_perm',), (self.user2, u'foo_perm',)])
-                        )
+        first = self.resource.users_for_perm(u'foo_perm', db_session=self.session)
+        second = [(self.user, u'foo_perm',), (self.user2, u'foo_perm',)]
+        if six.PY2:
+            return self.assertItemsEqual(first, second)
+        return self.assertCountEqual(first, second)
 
     def test_users_for_any_perm(self):
         self.__set_up_user_group_and_perms()
-        self.assertEqual(
-                sorted(self.resource.users_for_perm('__any_permission__',
-                                                    db_session=self.session)),
-                sorted([
-                        (self.user, u'group_perm',),
-                        (self.user, u'test_perm2',),
-                        (self.user, u'foo_perm',),
-                        (self.user2, u'foo_perm',),
-                        (self.user3, u'test_perm',),
-                        (self.user4, u'group_perm',),
-                        ])
-                )
+        first = self.resource.users_for_perm('__any_permission__',db_session=self.session)
+        second = [
+            (self.user, u'group_perm',),
+            (self.user, u'test_perm2',),
+            (self.user, u'foo_perm',),
+            (self.user2, u'foo_perm',),
+            (self.user3, u'test_perm',),
+            (self.user4, u'group_perm',),
+            ]
+        if six.PY2:
+            return self.assertItemsEqual(first, second)
+        return self.assertCountEqual(first, second)
 
 
 class GroupTestCase(BaseTestCase):
